--[[
******************************************************************
Script to copy the driver files to a known location where they can
be found by various driver components.

 ***** IMPORTANT NOTE *****
>> When this script is called at install time the calling script should set bOverwriteFiles to true.
>> When this script is called at uninstall time the calling script should set bOverwriteFiles to false.
******************************************************************
]]--

fDebug("\r\nCOPYING driver files...");

-- Create a folder name specific for the OS type (32-bit or 64-bit) to use later when building paths.
local OSTypeFolder = "";
if (System.Is64BitOS()) then
 	OSTypeFolder = "AMD64";
else
	OSTypeFolder = "i386";
end

-- initialize local variables
local bContinue = true;
local error = 0;
local pathCommonAppDataFolder = Shell.GetFolder(SHF_APPLICATIONDATA_COMMON);
local pathRootDriverFolder = pathCommonAppDataFolder.."\\Datacard\\XPS Card Printer";
local pathUSB = pathRootDriverFolder.."\\USB";
local pathUSBforOS = pathRootDriverFolder.."\\USB\\"..OSTypeFolder;
local pathNetwork = pathRootDriverFolder.."\\network";
local pathNetworkforOS = pathRootDriverFolder.."\\network\\"..OSTypeFolder;
local strUninstallExeName = pathRootDriverFolder.."\\dxp01uninst.exe";

local pathDocuments = pathRootDriverFolder.."\\Documentation";
local strStartMenu = Shell.GetFolder(SHF_STARTMENU_COMMON);
local pathDCCStartmenu = strStartMenu.."\\Datacard Printers";
local pathPolaroidStartmenu = strStartMenu.."\\Polaroid Printers";
local pathBonjour = pathRootDriverFolder.."\\Bonjour";

-- KCF 5-18-2012: Added the following block of code for v3.1 driver release
-- Get localized shortcut name from current language file if there is one.
local strUninstallShortcutName = "";
local strUninstallShortcutName = XML.GetValue("DXP01/UninstallStartMenuText");
if String.Length(strUninstallShortcutName) < 4 then -- 4 was an arbitrary number.
	strUninstallShortcutName = "XPS Card Printer Uninstall";
end

-- Make sure the overwrite flag is set to a valid state (true).
-- This protects against callers not implementing this variable and having its value be nil.
if (bOverwriteFiles ~= false) then
	bOverwriteFiles = true;
end

--[[
******************************************************************
Create folders to hold the driver files.
******************************************************************
 ]]--

-- Create root driver folder if it does not already exist.
if not (Folder.DoesExist(pathRootDriverFolder)) then
	Folder.Create(pathRootDriverFolder);
	error = Application.GetLastError();
	if (error ~= 0) then
		bContinue = false;
		fDebug("Creating root driver folder at "..pathRootDriverFolder.." failed with error: "..error);
	end
end

-- Create the USB folders if they do not already exist.
if bContinue then
	if not (Folder.DoesExist(pathUSBforOS)) then
		Folder.Create(pathUSBforOS);
		error = Application.GetLastError();
		if (error ~= 0) then
			bContinue = false;
			fDebug("Creating USB driver folder at "..pathUSBforOS.." failed with error: "..error);
		end
	end
end

-- Create Bonjour folder if it does not already exist.
if bContinue then
	if not (Folder.DoesExist(pathBonjour)) then
		Folder.Create(pathBonjour);
		error = Application.GetLastError();
		if (error ~= 0) then
			bContinue = false;
			fDebug("Creating Bonjour driver folder at "..pathBonjour.." failed with error: "..error);
		end
	end
end

-- Create the network folders if they do not already exist.
if bContinue then
	if not (Folder.DoesExist(pathNetworkforOS)) then
		Folder.Create(pathNetworkforOS);
		if (error ~= 0) then
			bContinue = false;
			fDebug("Creating network driver folder at "..pathNetworkforOS.." failed with error: "..error);
		end
	end
end

-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- Folders created... Next, copy all files to the folders.
-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
fDebug("  Folders located at: "..pathRootDriverFolder);

-- ***********************
-- *        DPINST       *
-- ***********************
-- Copy dpinst files from install dpinst folder to the root install folder.
-- OS independent file
if bContinue then
	File.Copy(_SourceFolder.."\\AutoPlay\\dpinst\\dpinst.xml", pathRootDriverFolder, false, bOverwriteFiles, true, true, nil);
	error = Application.GetLastError();
	if (error ~= 0) then
		bContinue = false;
		fDebug("Error: Driver file copy to "..pathRootDriverFolder.." failed with error: "..error);
	end
end

-- OS specific dpinst file
if bContinue then
	if (System.Is64BitOS()) then
		File.Copy(_SourceFolder.."\\AutoPlay\\dpinst\\dpinst64.exe", pathRootDriverFolder, false, bOverwriteFiles, true, true, nil);
	else
		File.Copy(_SourceFolder.."\\AutoPlay\\dpinst\\dpinst32.exe", pathRootDriverFolder, false, bOverwriteFiles, true, true, nil);
	end
	error = Application.GetLastError();
	if (error ~= 0) then
		bContinue = false;
		fDebug("Error: Driver file copy to "..pathRootDriverFolder.." failed with error: "..error);
	end
end

--[[
****************************************************
  Copy USB files
****************************************************
]]--

-- Copy the OS independent USB files.
if (bContinue) then
	File.Copy(_SourceFolder.."\\USB\\*.*", pathUSB, false, bOverwriteFiles, true, true, nil);
	error = Application.GetLastError();
	if (error ~= 0) then
		bContinue = false;
		fDebug("ERROR: Driver file copy to "..pathUSB.." failed with error: "..error);
	end
end

-- Copy OS specific USB files
if bContinue then
	File.Copy(_SourceFolder.."\\USB\\"..OSTypeFolder.."\\*.*", pathUSBforOS, false, bOverwriteFiles, true, true, nil);
	error = Application.GetLastError();
	if (error ~= 0) then
		bContinue = false;
		fDebug("ERROR: Driver file copy to "..pathUSBforOS.." failed with error: "..error);
	end
end


-- ***********************
-- *      Network        *
-- ***********************
-- Copy the OS independent network files.
if bContinue then
	File.Copy(_SourceFolder.."\\network\\*.*", pathNetwork, false, bOverwriteFiles, true, true, nil);
	error = Application.GetLastError();
	if (error ~= 0) then
		bContinue = false;
		fDebug("ERROR: Driver file copy to "..pathNetwork.." failed with error: "..error);
	end
end

-- Copy OS specific network files
if bContinue then
	File.Copy(_SourceFolder.."\\network\\"..OSTypeFolder.."\\*.*", pathNetworkforOS, false, bOverwriteFiles, true, true, nil);
	error = Application.GetLastError();
	if (error ~= 0) then
		bContinue = false;
		fDebug("ERROR: Driver file copy to "..pathNetworkforOS.." failed with error: "..error);
	end
end

-- ***********************
-- *      Uninstall      *
-- ***********************
-- Copy the Uninstall folder and subfolders. If this fails, the copy script continues.
if bContinue then
	-- HACK !
	-- OS Folder for uninstall is named differently than other
	-- change value of OSTypeFolder variable if 32 bit system.
	if not(System.Is64BitOS()) then
		OSTypeFolder = "x86";
	end

	-- Copy uninstall file
	File.Copy(_SourceFolder.."\\AutoPlay\\Uninstall\\"..OSTypeFolder.."\\dxp01uninst.exe", pathRootDriverFolder, false, bOverwriteFiles, true, true, nil);
	error = Application.GetLastError();
	if (error ~= 0) then
		fDebug("ERROR: Driver uninstall file copy to "..pathRootDriverFolder.." failed with error: "..error);
	end
	-- KCF 5-18-2012: Added the following block of code for v3.1 driver release
	-- Copy uninstall translated resource files
	File.Copy(_SourceFolder.."\\AutoPlay\\Uninstall\\*.dll", pathRootDriverFolder, false, bOverwriteFiles, true, true, nil);
	error = Application.GetLastError();
	if (error ~= 0) then
		fDebug("ERROR: Driver uninstall file copy to "..pathRootDriverFolder.." failed with error: "..error);
	end

	-- Undo HACK !
	-- Change it back just in case it is used again.
	if not(System.Is64BitOS()) then
		OSTypeFolder = "i386";
	end
end


--[[
*************************************************************************************************************
Copy Bonjour files cuz after network install, AutoPlay loses it's path and Driver letter to install Bonjour
**************************************************************************************************************
]]--

-- Copy the Bonjour USB files.
if (bContinue) then
	File.Copy(_SourceFolder.."\\AutoPlay\\Bonjour\\*.*", pathBonjour, false, bOverwriteFiles, true, true, nil);
	error = Application.GetLastError();
	if (error ~= 0) then
		bContinue = false;
		fDebug("ERROR: Driver file copy to "..pathBonjour.." failed with error: "..error);
	end
end


-- ***************************
-- * unistall shortcut       *
-- ***************************
if (bContinue) then
--	fDebug("ERROR: Driver uninstall file copy to "..pathRootDriverFolder.." failed with error: "..error);


	fDebug("INFO: name of uninstall file is "..strUninstallExeName);
	fDebug("INFO: name of shortcut is "..strUninstallShortcutName);

	if OEMDetected then
		if (OEMTag == "OEM01") then -- Polaroid
			fDebug("INFO: shortcut path is "..pathPolaroidStartmenu);
			Shell.CreateShortcut(pathPolaroidStartmenu, strUninstallShortcutName, strUninstallExeName, "", "", "", 0, SW_SHOWNORMAL, nil);
		end
	else
		fDebug("INFO: shortcut path is "..pathDCCStartmenu);
		Shell.CreateShortcut(pathDCCStartmenu, strUninstallShortcutName, strUninstallExeName, "", "", "", 0, SW_SHOWNORMAL, nil);
	end

	fDebug("INFO: completed adding shortcut to startmenu");
end

-- Send a signal back to the main script using the bContinueInstall flag.
if (bContinue) then
	bContinueInstall = true;
	fDebug("SUCCESS: Driver files copied.");
else
	bContinueInstall = false;
	fDebug("FAIL: Driver files not copied.");
end
